"submodule foreach" much slower than removed "submodule--helper --list"
- From
Jonas Bernoulli <jonas@bernoul.li>
- Date
- Oct 15, 2022, 16:50 UTC
- Message-ID
- <87czatrpyb.fsf@bernoul.li>
In v2.38.0 (31955475d1c283120d5d84247eb3fd55d9f5fdd9) "submodule--helper --list" was remove because
> We're not getting anything useful from the "list | cut -f2" > invocation that we couldn't get from "foreach 'echo $sm_path'".
But we get speed (this is with about one hundred modules):
$ time git submodule foreach -q 'echo $sm_path' > /dev/null
real 0m0.585s user 0m0.413s sys 0m0.182s
$ time git submodule--helper list > /dev/null
real 0m0.008s user 0m0.004s sys 0m0.004s
Please consider restoring this subcommand or providing something equivalent that is just as fast.
Thanks,
Jonas